pub struct Rule {
    pub name: String,
    pub names: Vec<String>,
    pub type: String,
    pub packages: Vec<String>,
    pub distribution: Vec<String>,
    pub certificates: Vec<String>,
    pub websites: Vec<String>,
    pub c2: C2Rule,
}
A rule entry that lists indicators of compromise for a strain of stalkerware

Fields

name: String

A canonical name for this strain

names: Vec<String>

Other names this stalkerware is known as

type: String

The kind of app, either stalkerware or watchware

packages: Vec<String>

App identifiers this stalkerware uses

distribution: Vec<String>

Domains that are involved in distributing the app itself (eg. the .apk)

certificates: Vec<String>

Certificates that are in use with this stalkerware

websites: Vec<String>

Websites that are related to this stalkerware (eg. marketing or panels)

c2: C2Rule

Domains and IP addresses that are used by C2 infrastructure